@@ -1,4 +1,4 @@
-/* init.c - MemTest-86  Version 3.3
+/* init.c - MemTest-86  Version 3.4
  *
  * Released under version 2 of the Gnu Public License.
  * By Chris Brady
@@ -15,8 +15,11 @@
 #include "pci.h"
 #include "io.h"
 
+extern struct tseq tseq[];
 extern short memsz_mode;
 extern short firmware;
+extern short dmi_initialized;
+extern int dmi_err_cnts[MAX_DMI_MEMDEVS];
 
 int l1_cache=0, l2_cache=0;
 struct cpu_ident cpu_id;
@@ -52,7 +55,7 @@ static void display_init(void)
 	for(i=0, pp=(char *)(SCREEN_ADR+1); i<TITLE_WIDTH; i++, pp+=2) {
 		*pp = 0x47;
 	}
-	cprint(0, 0, "      Memtest-86 v3.3       ");
+	cprint(0, 0, "      Memtest-86 v3.4       ");
 
 	/* Do reverse video for the bottom display line */
 	for(i=0, pp=(char *)(SCREEN_ADR+1+(24 * 160)); i<80; i++, pp+=2) {
@@ -94,9 +97,36 @@ void init(void)
 	pci_init();
 
 	v->test = 0;
+	v->pass = 0;
+	v->msg_line = 0;
+	v->ecount = 0;
+	v->ecc_ecount = 0;
 	v->testsel = -1;
 	v->msg_line = LINE_SCROLL-1;
 	v->scroll_start = v->msg_line * 160;
+	v->erri.low_addr.page = 0x7fffffff;
+	v->erri.low_addr.offset = 0xfff;
+	v->erri.high_addr.page = 0;
+	v->erri.high_addr.offset = 0;
+	v->erri.min_bits = 32;
+	v->erri.max_bits = 0;
+	v->erri.min_bits = 32;
+	v->erri.max_bits = 0;
+	v->erri.maxl = 0;
+	v->erri.cor_err = 0;
+	v->erri.ebits = 0;
+	v->erri.hdr_flag = 0;
+	v->erri.tbits = 0;
+	for (i=0; tseq[i].msg != NULL; i++) {
+		tseq[i].errors = 0;
+	}
+	if (dmi_initialized) {
+		for (i=0; i < MAX_DMI_MEMDEVS; i++){
+			if (dmi_err_cnts[i] > 0) {
+				dmi_err_cnts[i] = 0;
+			}
+		}
+	}
 
 	cprint(LINE_CPU+1, 0, "L1 Cache: Unknown ");
 	cprint(LINE_CPU+2, 0, "L2 Cache: Unknown ");
@@ -136,7 +166,7 @@ void init(void)
 		cprint(i, COL_MID-2, "| ");
 	}
 	footer();
-	v->printmode=PRINTMODE_ADDRESSES;
+	v->printmode=PRINTMODE_SUMMARY;
 	v->numpatn=0;
 	find_ticks();
 }
@@ -210,6 +240,17 @@ int map_page(unsigned long page)
 	}
 	/* Compute the page table entries... */
 	for(i = 0; i < 1024; i++) {
+		/*-----------------10/30/2004 12:37PM---------------
+		 * 0xE3 --
+		 * Bit 0 = Present bit.      1 = PDE is present
+		 * Bit 1 = Read/Write.       1 = memory is writable
+		 * Bit 2 = Supervisor/User.  0 = Supervisor only (CPL 0-2)
+		 * Bit 3 = Writethrough.     0 = writeback cache policy
+		 * Bit 4 = Cache Disable.    0 = page level cache enabled
+		 * Bit 5 = Accessed.         1 = memory has been accessed.
+		 * Bit 6 = Dirty.            1 = memory has been written to.
+		 * Bit 7 = Page Size.        1 = page size is 2 MBytes
+		 * --------------------------------------------------*/
 		pd2[i].addr_lo = ((window & 1) << 31) + ((i & 0x3ff) << 21) + 0xE3;
 		pd2[i].addr_hi = (window >> 1);
 	}
@@ -364,6 +405,7 @@ void cpu_type(void)
 			case 2:
 			case 3:
 				cprint(LINE_CPU, 0, "AMD K5");
+				l1_cache = 8;
 				off = 6;
 				break;
 			case 6:
@@ -440,9 +482,14 @@ void cpu_type(void)
 				if (cpu_id.step == 0) { /* stepping 0 */
 					/* Hard code the right L2 size */
 					l2_cache = 64;
+				} else {
+					l2_cache = (cpu_id.cache_info[11] << 8);
+					l2_cache += cpu_id.cache_info[10];
 				}
 				break;
 			}
+			l1_cache = cpu_id.cache_info[3];
+			l1_cache += cpu_id.cache_info[7];
 			break;
 		case 15:
 			/* Get L1 & L2 cache sizes */
@@ -470,6 +517,10 @@ void cpu_type(void)
 				cprint(LINE_CPU, 0, "Athlon 64 X2");
 				off = 12;				
 				break;
+			case 8:
+				cprint(LINE_CPU, 0, "Turion 64 X2");
+				off = 12;
+				break;
 			case 4:
 			case 7:
 			case 9:
@@ -580,22 +631,31 @@ void cpu_type(void)
 			case 0x3b:
 				l2_cache = 128;
 				break;
+			case 0x3a:
+				l2_cache = 192;
+				break;
 			case 0x42:
 			case 0x7a:
 			case 0x82:
 			case 0x3c:
 				l2_cache = 256;
 				break;
+			case 0x3d:
+				l2_cache = 384;
+				break;
 			case 0x43:
 			case 0x7b:
 			case 0x83:
 			case 0x86:
+			case 0x3e:
+			case 0x7f:
 				l2_cache = 512;
 				break;
 			case 0x44:
 			case 0x7c:
 			case 0x84:
 			case 0x87:
+			case 0x78:
 				l2_cache = 1024;
 				break;
 			case 0x45:
@@ -603,6 +663,9 @@ void cpu_type(void)
 			case 0x85:
 				l2_cache = 2048;
 				break;
+			case 0x49:
+				l2_cache = 4096;
+				break;
 			}
 		}
 
@@ -693,6 +756,14 @@ void cpu_type(void)
 				}
 				off = 16;
 				break;
+			case 14:
+				cprint(LINE_CPU, 0, "Intel Core");
+				off = 10;
+				break;				
+			case 15:
+				cprint(LINE_CPU, 0, "Intel Core 2");
+				off = 12;
+				break;
 			}
 			break;
 		case 15:
@@ -729,6 +800,7 @@ void cpu_type(void)
 				}
 				break;
 			case 3:
+			case 4:
 				if (l2_cache == 256) {
 					cprint(LINE_CPU, 0, "Celeron (0.09)");
 					off = 14;	
@@ -738,15 +810,18 @@ void cpu_type(void)
 				} else if (cpu_id.pwrcap == 0x0C) {
 					cprint(LINE_CPU, 0, "Xeon MP (0.09)");
 					off = 14;
+				} else if ((cpu_id.step == 0x4 || cpu_id.step == 0x7) && cpu_id.model == 0x4) {
+					cprint(LINE_CPU, 0, "Pentium D (0.09)");
+					off = 16;
 				} else {
 					cprint(LINE_CPU, 0, "Pentium 4 (0.09)");
 					off = 16;
 				}
 				break;
- 			case 4:
-				cprint(LINE_CPU, 0, "Pentium D (0.09)");
-   				off = 16;		
- 				break;
+			case 6:
+				cprint(LINE_CPU, 0, "Pentium D (65nm)");
+				off = 16;		
+				break;
 			default:
 				cprint(LINE_CPU, 0, "Unknown Intel");
 				off = 13;	
@@ -843,14 +918,14 @@ void cpu_type(void)
 
 	/* Print CPU speed */
 	if ((speed = cpuspeed()) > 0) {
-		if (speed < 999500) {
+		if (speed < 999499) {
 			speed += 50; /* for rounding */
 			cprint(LINE_CPU, off, "    . MHz");
 			dprint(LINE_CPU, off+1, speed/1000, 3, 1);
 			dprint(LINE_CPU, off+5, (speed/100)%10, 1, 0);
 		} else {
 			speed += 500; /* for rounding */
-			cprint(LINE_CPU, off, "      Mhz");
+			cprint(LINE_CPU, off, "      MHz");
 			dprint(LINE_CPU, off, speed/1000, 5, 0);
 		}
 		extclock = speed;
