@@ -1,4 +1,4 @@
-/* lib.c - MemTest-86  Version 3.3
+/* lib.c - MemTest-86  Version 3.4
  *
  * Released under version 2 of the Gnu Public License.
  * By Chris Brady
@@ -87,6 +87,7 @@ void *memmove(void *dest, const void *src, ulong n)
 	}
 	return dest;
 }
+
 /*
  * Scroll the error message area of the screen as needed
  * Starts at line LINE_SCROLL and ends at line 23
@@ -124,7 +125,22 @@ void scroll(void)
 }
 
 /*
- * Print characters on screen
+ * Clear scroll region
+ */
+void clear_scroll(void)
+{
+	int i;
+	char *s;
+
+	s = (char*)(SCREEN_ADR+LINE_HEADER*160);
+        for(i=0; i<80*(24-LINE_HEADER); i++) {
+                *s++ = ' ';
+                *s++ = 0x17;
+        }
+}
+
+/*
+ * Print characters (n screen
  */
 void cprint(int y, int x, const char *text)
 {
@@ -282,6 +298,34 @@ void hprint2(int y,int x, unsigned long val, int digits)
 	cprint(y,x,buf + (idx - digits));
 }
 
+/*
+ * Print a hex number on screen exactly digits long
+ */
+void hprint3(int y,int x, unsigned long val, int digits)
+{
+	unsigned long j;
+	int i, idx, flag = 0;
+
+	for (i=0, idx=0; i<digits; i++) {
+		j = 0xf & val;
+		val /= 16;
+
+		if (j < 10) {
+			if (flag || j || i == 7) {
+				buf[digits - ++idx] = j + '0';
+				flag++;
+			} else {
+				buf[digits - ++idx] = '0';
+			}
+		} else {
+			buf[digits - ++idx] = j + 'a' - 10;
+			flag++;
+		}
+	}
+	buf[idx] = 0;
+	cprint(y,x,buf);
+}
+
 /*
  * Print a hex number on screen
  */
@@ -328,7 +372,7 @@ void inter(struct eregs *trap_regs)
 #endif
 
 	/* clear scrolling region */
-        pp=(char *)(SCREEN_ADR+(2*80*(LINE_SCROLL-2)));
+        pp=(unsigned char *)(SCREEN_ADR+(2*80*(LINE_SCROLL-2)));
         for(i=0; i<2*80*(24-LINE_SCROLL-2); i++, pp+=2) {
                 *pp = ' ';
         }
