@@ -1,4 +1,4 @@
-/* main.c - MemTest-86  Version 3.3
+/* main.c - MemTest-86  Version 3.4
  *
  * Released under version 2 of the Gnu Public License.
  * By Chris Brady
@@ -19,7 +19,7 @@ const struct tseq tseq[] = {
 	{1, 7, 64, 66, 0,  "[Block move, 64 moves]                "},
 	{1, 2, 2, 320, 0,  "[Moving inversions, 32 bit pattern]   "},
 	{1, 9, 40, 120, 0, "[Random number sequence]              "},
-        {1, 11, 6, 2880, 0,"[Modulo 20, Random pattern]           "},
+        {1, 11, 6, 1920, 0,"[Modulo 20, Random pattern]           "},
 	{1, 8, 1, 2, 0,    "[Bit fade test, 90 min, 2 patterns]   "},
 	{0, 0, 0, 0, 0, NULL}
 };
@@ -34,13 +34,15 @@ ulong p1 = 0, p2 = 0, p0 = 0;
 int segs = 0, bail = 0;
 int test_ticks;
 int nticks;
+ulong high_test_adr = 0x200000;
 
 static int window = 0;
 static struct pmap windows[] = 
 {
-	{ 0/* Written at startup */, 0x100000 },
-	{ 0, RES_START >> 12 },
+	{ 0/* Written at startup */, 0x080000 },	/* first 2gb */
+	{ 0, 0/* Written at startup */ },		/* for relocation */
 
+	{ 0x080000, 0x100000 },				/* 2nd 2gb */
 	{ 0x100000, 0x180000 },
 	{ 0x180000, 0x200000 },
 
@@ -87,9 +89,6 @@ static struct pmap windows[] =
 	{ 0xF80000, 0x1000000 },
 };
 
-#if (LOW_TEST_ADR >= HIGH_TEST_ADR)
-#error LOW_TEST_ADR and HIGH_TEST_ADR may not overlap
-#endif
 #if (LOW_TEST_ADR > (640*1024))
 #error LOW_TEST_ADR must be below 640K
 #endif
@@ -119,8 +118,8 @@ static void run_at(unsigned long addr)
 	if (	((start < addr) && ((start + len) >= addr)) || 
 		((addr < start) &&  ((addr + len) >= start))) {
 		/* Handle overlap by doing an extra relocation */
-		if (addr + len < HIGH_TEST_ADR) {
-			__run_at(HIGH_TEST_ADR);
+		if (addr + len < high_test_adr) {
+			__run_at(high_test_adr);
 		}
 		else if (start + len < addr) {
 			__run_at(LOW_TEST_ADR);
@@ -147,9 +146,15 @@ void do_test(void)
 		if ((ulong)&_start != LOW_TEST_ADR) {
 			restart();
 		}
+		init();
 		windows[0].start = 
 			( LOW_TEST_ADR + (_end - _start) + 4095) >> 12;
-		init();
+
+		/* Set relocation address at 16Mb if there is enough memory */
+		if (v->pmap[v->msegs-1].end > 0x1100) {
+			high_test_adr = 0x1000000;
+		}
+		windows[1].end = (high_test_adr >> 12);
 		firsttime = 1;
 	}
 	bail = 0;
@@ -174,40 +179,12 @@ void do_test(void)
 
 	/* Update display of memory segments being tested */
 	lo = page_of(v->map[0].start);
-	hi = page_of(v->map[segs -1].end);
+	hi = page_of(v->map[segs-1].end);
 	aprint(LINE_RANGE, COL_MID+9, lo);
 	cprint(LINE_RANGE, COL_MID+14, " - ");
 	aprint(LINE_RANGE, COL_MID+17, hi);
 	aprint(LINE_RANGE, COL_MID+23, v->selected_pages);
 	
-#ifdef TEST_TIMES
-	{
-		ulong l, h, t;
-		
-		asm __volatile__ (
-			"rdtsc\n\t"
-			"subl %%ebx,%%eax\n\t"
-			"sbbl %%ecx,%%edx\n\t"
-			:"=a" (l), "=d" (h)
-			:"b" (v->snapl), "c" (v->snaph)
-		);
-
-		cprint(20, 5, ":  :");
-		t = h * ((unsigned)0xffffffff / v->clks_msec) / 1000;
-		t += (l / v->clks_msec) / 1000;
-		i = t % 60;
-		dprint(20, 10, i%10, 1, 0);
-		dprint(20, 9, i/10, 1, 0);
-		t /= 60;
-		i = t % 60;
-		dprint(20, +7, i % 10, 1, 0);
-		dprint(20, +6, i / 10, 1, 0);
-		t /= 60;
-		dprint(20, 0, t, 5, 0);
-
-		asm __volatile__ ("rdtsc":"=a" (v->snapl),"=d" (v->snaph));
-	}
-#endif
 	/* Now setup the test parameters based on the current test number */
 	/* Figure out the next test to run */
 	if (v->testsel >= 0) {
@@ -372,16 +349,16 @@ void do_test(void)
 		/* Relocate and run the high copy if:
 		 * - The window overwrites us.
 		 *   The lower limit is less than START_ADR
-		 * - There is more than 1 meg of memory
+		 * - There is enough memory
 		 */
 		if (windows[window].start < 
-			(LOW_TEST_ADR + (_end - _start)) >> 12) {
+			((ulong)&_start + (_end - _start)) >> 12) {
 			if (v->pmap[v->msegs-1].end > 
-				(((HIGH_TEST_ADR + (_end - _start)) >> 12) +1)) {
+				(((high_test_adr + (_end - _start)) >> 12)+1)) {
 				/* We need the high copy and we have enough
 				 * memory so use it.
 				 */
-				run_at(HIGH_TEST_ADR);
+				run_at(high_test_adr);
 			} else { 
 				/* We can't use this window so skip it */
 				goto skip_window;
@@ -465,7 +442,7 @@ void find_ticks(void)
 	}
 	compute_segments(window);
 	window = 0;
-	for (v->pass_ticks=0, i=0; i<DEFTESTS != NULL; i++) {
+	for (v->pass_ticks=0, i=0; i<DEFTESTS; i++) {
 
 		/* Test to see if this test is selected for execution */
 		if (v->testsel >= 0) {
@@ -552,6 +529,7 @@ static void compute_segments(int win)
 
 		cprint(LINE_SCROLL+(2*i+1), 44, "i=");
 		hprint(LINE_SCROLL+(2*i+1), 46, i);
+		init();
 		
 		cprint(LINE_SCROLL+(2*i+2), 0, 
 			"                                        "
