@@ -5,6 +5,7 @@
  */
 
 
+#define MAX_DMI_MEMDEVS 16
 #define E88     0x00
 #define E801    0x04
 #define E820NR  0x08           /* # entries in E820MAP */
@@ -35,7 +36,7 @@ struct mem_info_t {
 };
 
 typedef unsigned long ulong;
-#define SPINSZ		0x800000
+#define SPINSZ		0x1000000 /* 1mb */
 #define MOD_SZ		20
 #define BAILOUT		if (bail) goto skip_test;
 #define BAILR		if (bail) return;
@@ -70,17 +71,16 @@ typedef unsigned long ulong;
 #define LINE_MSG	18
 #define COL_MSG		18
 
-#define POP_W	30
+#define POP_W	34
 #define POP_H	15
 #define POP_X	16
 #define POP_Y	8
-#define NULL	0
+#define POP2_W  74
+#define POP2_H  21
+#define POP2_X  3
+#define POP2_Y  2
 
-/* sizeof spd window */
-#define SPD_W   51      
-#define SPD_H   19      
-#define SPD_X   16
-#define SPD_Y   4       
+#define NULL	0
 
 /* memspeed operations */
 #define MS_COPY		1
@@ -108,6 +108,7 @@ void ttyprintc(int y, int x, char c);
 void cprint(int y,int x, const char *s);
 void hprint(int y,int x,ulong val);
 void hprint2(int y,int x, ulong val, int len);
+void hprint3(int y,int x, ulong val, int len);
 void xprint(int y,int x,ulong val);
 void aprint(int y,int x,ulong page);
 void dprint(int y,int x,ulong val,int len, int right);
@@ -128,9 +129,13 @@ void set_cache(int val);
 void check_input(void);
 void footer(void);
 void scroll(void);
+void clear_scroll(void);
 void popup(void);
 void popdown(void);
 void popclear(void);
+void pop2up(void);
+void pop2down(void);
+void pop2clear(void);
 void get_config(void);
 void get_menu(void);
 void get_printmode(void);
@@ -156,15 +161,18 @@ void start_config(void);
 void clear_screen(void);
 void paging_off(void);
 void show_spd(void);
+void add_dmi_err(ulong adr);
+void print_dmi_info(void);
 int map_page(unsigned long page);
 void *mapping(unsigned long page_address);
 void *emapping(unsigned long page_address);
 ulong memspeed(ulong src, ulong len, int iter, int type);
 unsigned long page_of(void *ptr);
 
-#define PRINTMODE_ADDRESSES 0
-#define PRINTMODE_PATTERNS  1
-#define PRINTMODE_NONE      2
+#define PRINTMODE_SUMMARY   0
+#define PRINTMODE_ADDRESSES 1
+#define PRINTMODE_PATTERNS  2
+#define PRINTMODE_NONE      3
 
 #define BADRAM_MAXPATNS 10
 
@@ -249,6 +257,26 @@ struct cpu_ident {
 	long pwrcap;
 	long ext;
 };
+
+struct xadr {
+	ulong page;
+	ulong offset;
+};
+
+struct err_info {
+	struct xadr   low_addr;
+	struct xadr   high_addr;
+	unsigned long ebits;
+	long	      tbits;
+	short         min_bits;
+	short         max_bits;
+	unsigned long maxl;
+	unsigned long eadr;
+        unsigned long exor;
+        unsigned long cor_err;
+	short         hdr_flag;
+};
+
 #define X86_FEATURE_PAE		(0*32+ 6) /* Physical Address Extensions */
 
 #define MAX_MEM_SEGMENTS E820MAX
@@ -257,8 +285,6 @@ struct cpu_ident {
 struct vars {
 	int test;
 	int pass;
-	unsigned long *eadr;
-	unsigned long exor;
 	int msg_line;
 	int ecount;
 	int ecc_ecount;
@@ -271,6 +297,7 @@ struct vars {
 	int total_ticks;
 	int pptr;
 	int tptr;
+	struct err_info erri;
 	struct pmap pmap[MAX_MEM_SEGMENTS];
 	struct mmap map[MAX_MEM_SEGMENTS];
 	ulong plim_lower;
